<?php defined('KERNEL_INCLUDED') or die('kernel should be included first');
// This file is part of DENIF, distributed under license GPLv3.
// Copyright 2006 Guillaume Ryder, Arthur Charguraud

//-----------------------------------------------------------------
/// @file
/// @brief Constants and settings for the site.
///
/// This file includes a local configuration file, <tt>conf-local.inc.php</tt>,
/// and a secondary instance configuration file (if present), <tt>conf-secondary.inc.php</tt>,
///
/// See <tt>../doc/configuration.txt</tt> for detailed instructions about how to configure DENIF.
//-----------------------------------------------------------------


//-----------------------------------------------------------------
/// @name Local configuration
///
/// The local configuration is specific to a version of the site, such as production or development.
/// It contains settings such as SQL database credentials, or the debugging flag (bLocal).
///
/// The configuration is stored in <tt>conf-local.inc.php</tt> (see <tt>conf-local-template.inc.php</tt> for a template of this file).
/// The file is expected to call <tt>sql::setup(host, login, password, database)</tt>.
/// @{
//-----------------------------------------------------------------

date_default_timezone_set('Europe/Paris');

ini_set('memory_limit', '512M');

require_once 'conf-local.inc.php';

if (!defined('sql_sHost'))
	debug::fatalError('SQL server not defined: call sql::setup() in conf-local.inc.php');

/// @brief Indicate if the site is local, for coding and testing only.
defineDefault('bLocal', false);

/// @brief Force the right pane in AJAX documents editing interface
/// to display http://localhost/ instead of the docgroup URL.
defineDefault('bWebPaneLocalhost', bLocal);

/// @brief Indicate whether the server supports email sending.
/// If enabled, adds a contact form to the site.
defineDefault('bCanSendEmail', false);

/// @brief Authors of the primary instance of DENIF.
defineDefault('sPrimaryInstanceAuthor', 'Guillaume Ryder, Arthur Charguraud');

/// @}


//-----------------------------------------------------------------
/// @name Instance-specific configuration
///
/// The primary instance of DENIF is the official site, hosted on http://denif.ens-lyon.fr.
/// Other instances of DENIF can be defined under different names, to host different documents.
///
/// Secondary instances must have a file <tt>conf-secondary.inc.php</tt> setting various parameters.
/// If this file does not exist, the site is assumed to be the primary instance of DENIF.
/// @{
//-----------------------------------------------------------------

/// @brief Credits for all authors of the site, displayed on the home page. One credit line per array element.
$aAuthorCredit = array(
	html::link('http://arthur.chargueraud.org/', 'Arthur Charguraud') . ' avait ralis un premier site analogue&nbsp;; il a particip  la conception du site actuel et apport une bonne partie du contenu de la base de donnes.',
	html::link('http://www.gryder.org/', 'Guillaume Ryder') . ' a conu et implment la version actuelle du site, en particulier les outils dadministration qui permettent dajouter des documents en quelques clics.',
);

/// @brief Whether this is the primary instance of DENIF, or a secondary instance.
///
/// Must be set to false by any site that reuses DENIF engine.
/// This constant is set according to the existence of the file conf-secondary.inc.php.
define('bPrimaryInstance', (@include_once 'conf-secondary.inc.php') === false);

if (bPrimaryInstance) {
	// Defaults for the primary instance of DENIF.
	
	require_once 'conf-primary.inc.php';
	
}else{
	// Defaults for secondary instances of DENIF.
	
	if (defined('sSecondaryInstanceAuthor') && sSecondaryInstanceAuthor)
		defineDefault('sInstanceAuthor', sPrimaryInstanceAuthor . ', ' . sSecondaryInstanceAuthor);
	
	defineDefault('sExternalGoogleAnalyticsId', '');
	defineDefault('sGoogleCSEId', '');
}

/// @brief Authors of the site, including authors of the primary instance.
/// Used in the <tt>\<meta\></tt> author tag.
defineDefault('sInstanceAuthor', sPrimaryInstanceAuthor);

/// @brief Checks that all constants are defined.
function ConstantsSanityCheck() {
	$aRequiredConstant = getList('sInstanceAcronym;sInstanceTitle;sInstanceDescriptionShort;sInstanceDescriptionMedium;sInstanceDescriptionLong;sContactEmail;sWebDataPath;sExternalGoogleAnalyticsId;sGoogleCSEId');
	foreach ($aRequiredConstant as $sConstant)
		if (!defined($sConstant))
			debug::fatalError('The following constant must be defined: ' . $sConstant);
}

ConstantsSanityCheck();

/// @}


//-----------------------------------------------------------------
/// @name Paths, text information
/// @{
//-----------------------------------------------------------------

umask(0);

/// Root directory used to store the cached files.
defineDefault('sDataPath', sRootRel . 'data/');

/// Prefix of all temporary files; should have only 3 characters.
defineDefault('sTempFilePrefix', 'dnf');

/// @brief Characters that can't be used in node::$sPathPart.
defineDefault('sDataPathPartInvalidCharsSpec', path::sInvalidCharsSpec . ' \'');

/// Maximum size of a cached file, in bytes.
defineDefault('maxCacheFileSize', 30 << 20);

/// Maximum size of a generated Zip file, in bytes.
defineDefault('maxZipTotalSize', 50 << 20);

/// @brief Maximum filename length of every file in a generated Zip.
defineDefault('maxLengthZipFileName', 30);

/// @brief Unix rights of the data directories.
/// Should be an octal number, for example: \c 0770.
defineDefault('iDataUnixRightsDirs', 0770);

/// @brief Unix rights of the data files.
/// Should be an octal number, for example: \c 0660.
defineDefault('iDataUnixRightsFiles', 0660);

/// @brief Unix group of the data files and directories.
defineDefault('sDataUnixGroup', 'denif');

/// @brief E-mail subject used by resources proposition form.
defineDefault('sEmailSubjectPropose', '[Proposition]');

/// @brief E-mail subject used by contact form.
defineDefault('sEmailSubjectContact', '[Contact]');

/// Used by the Ajax edit page: default URL for the right panel
defineDefault('sDefaultURL', 'http://localhost/');

/// The copyright notice displayed at the bottom of all pages.
defineDefault('sDocumentsCopyrightNotice', 'Les documents rfrencs sur ce site sont la proprit intellectuelle de leurs auteurs respectifs. Ne pas les reproduire sans autorisation.');

/// The link to the primary instance of DENIF.
defineDefault('sPrimaryInstanceLink', html::link('http://denif.ens-lyon.fr', 'DENIF'));

/// The link to the GPL license applied to DENIF.
defineDefault('sLicenseLink', html::link('http://www.gnu.org/licenses/gpl-3.0.html', 'GPLv3'));

/// The information notice displayed at the bottom of all pages if the instance is not the primary instance.
defineDefault('sPrimaryInstanceLicense', 'Le code source de ce site est plac sous licence ' . sLicenseLink . '.');

/// The URL to the primary DENIF source archive.
defineDefault('sPrimarySourceDownloadUrl', 'http://denif.ens-lyon.fr/denif-src.zip');

/// The information notice displayed at the bottom of all pages if the instance is not the primary instance.
defineDefault('sSecondaryInstanceLicense', 'Ce site utilise '. sPrimaryInstanceLink . ', conu par des lves de lENS Lyon et distribu sous licence ' . sLicenseLink . '.');

/// @brief Prefix of DENIF specific URL parameters that can be appended to the URLs.
///
/// - \c DENIF_bNoWebOpen: to prevent the URL from being opened by default by the right panel
///    of the Ajax documents interface. Useful with URLs that create frames, have Javascript errors, etc.
/// - \c DENIF_bForceDownload: to force the pointed file to be downloaded.
///   By default, <tt>*.htm[l]</tt> and <tt>*.php</tt> files are not downloaded.
defineDefault('sParamPrefix', 'DENIF_');

/// @brief Files having one of these extensions are not downloaded by default.
/// In particular, URLs having no extension (directories) are not downloaded.
/// The \c DENIF_bForceDownload will allow downloading.
defineDefault('sURLNoDownloadExts', ';html;htm;php');

/// @brief ID of the Google Analytics tracer, put at the end of each page.
/// If empty, the Google Analytics tracer is disabled.
/// @see sExternalGoogleAnalyticsId
defineDefault('sGoogleAnalyticsId', (bLocal) ? '' : sExternalGoogleAnalyticsId);

/// @brief If \c true, internal Google search is enabled
/// and uses #sGoogleCSEId as Custom Search Engine ID.
defineDefault('bGoogleSearch', isSome(sGoogleCSEId));

/// @brief Login sessions inactivity timeout, in seconds. 15 minutes by default.
defineDefault('timeoutSessionSeconds',           15 * 60);

/// @brief Login cookie inactivity timeout, in seconds. 30 days by default.
defineDefault('timeoutCookieSeconds',  30 * 24 * 60 * 60);

/// @brief Minimum Levenshtein distance between two teacher names
/// for them to be considered as very similar.
/// Used by Maintenance::findInvalid() to report about duplicates in the database.
defineDefault('levenshteinThresholdNames', 3);

/// @}


//-----------------------------------------------------------------
/// @name Default rights, used by inheritance mechanism
/// @{
//-----------------------------------------------------------------

defineDefault('visibleDefault',   visibleYes);
defineDefault('finalDefault',     finalYes);
defineDefault('cacheReqDefault',  cacheReqYes);
defineDefault('cacheVisDefault',  cacheVisYes);
defineDefault('cacheAuthDefault', cacheAuthUnknown);

/// @}


//-----------------------------------------------------------------
/// @name Limits
/// @{
//-----------------------------------------------------------------

defineDefault('maxLengthTitle', 1000);
defineDefault('maxLengthShort',  255);
defineDefault('maxLengthURL',    255);
defineDefault('maxLengthEmail',  255);
defineDefault('maxLengthSearch', 200);
defineDefault('maxLengthID',      20);

/// @}


//-----------------------------------------------------------------
/// @name Pinging and downloading scripts
/// @{
//-----------------------------------------------------------------

/// @brief Maximum execution duration of a script.
/// This is an approximated value: to avoid process killing,
/// some scripts may execute longer.
defineDefault('maxTimeScriptsSeconds', 3 * 60);

/// @brief Absolute maximum execution duration of a script.
/// If a PHP script tries to run longer, it will be killed.
defineDefault('maxTimeScriptsSecondsHard', maxTimeScriptsSeconds + 60);

/// @brief Name of the lock file used by external scripts.
///
/// To acquire the mutex, the modification time of the mutex file is examined.
/// The mutex file is <tt>touch()</tt>'d once the mutex is acquired.
/// @see nbMutexTimeoutSeconds
defineDefault('sMutexFile', 'scripts.lock');

/// @brief Timeout after which the mutex is considered as unacquired.
/// @see sMutexFile
defineDefault('nbMutexTimeoutSeconds', maxTimeScriptsSeconds * 2);

/// @brief User-Agent used by the pinging and downloading scripts.
defineDefault('sUserAgent', 'PHP DENIF');

/// @}


?>